from bs4 import BeautifulSoup
import os


def all_html_files(path=os.getcwd()):
    """Return a list of all html files in the given directory"""
    files = []
    for file in os.listdir(path):
        if file.endswith('.html'):
            files.append(file)

    return files


def mark_class(soup: BeautifulSoup):
    header = soup.select_one('body div.header h1.symbol')
    if header != None and 'class ' in header.text:
        if 'symbol-class' not in header['class']:
            header['class'].append('symbol-class')

        h2_list = soup.select('#content > h2')
        for h2 in h2_list:
            mark_enum_and_type(h2)


def mark_struct(soup: BeautifulSoup):
    header = soup.select_one('body div.header h1.symbol')
    if header != None and 'struct ' in header.text:
        if 'symbol-struct' not in header['class']:
            header['class'].append('symbol-struct')

        h2_list = soup.select('#content > h2')
        for h2 in h2_list:
            mark_enum_and_type(h2)


def mark_package(soup: BeautifulSoup):
    header = soup.select_one('body div.header h1.title')
    if header != None and 'Package ' in header.text and 'symbol-package' not in header['class']:
        header['class'].append('symbol-package')


def mark_namespace(soup: BeautifulSoup):
    header = soup.select_one('body div.header h1.symbol')
    if header != None and 'namespace ' in header.text:
        if 'symbol-namespace' not in header['class']:
            header['class'].append('symbol-namespace')

        h2_list = soup.select('#content > h2')
        for h2 in h2_list:
            mark_enum_and_type(h2)


def mark_enum_and_type(soup: BeautifulSoup):
    if 'Types' in soup.text and 'Types Aliases' not in soup.text:
        target = soup.next_sibling
        while target != None and target.name != 'h2':
            if target.name == 'h3':
                tmp = BeautifulSoup(str(target), 'html.parser')
                target_a = tmp.select_one('a')
                if not target_a:
                    pass
                elif target_a.has_attr('class') and 'symbol-types' not in target_a['class']:
                    target_a['class'].append('symbol-types')
                    target.a.replace_with(target_a)
                else:
                    target_a['class'] = ['symbol-types']
                    target.a.replace_with(target_a)
            target = target.next_sibling
        return
    # if 'Enumerations' in soup.text:
    #     target = soup.next_sibling
    #     while target != None and target.name != 'h2':
    #         if target.name == 'h3':
    #             next_iter = 2
    #             tmp_decl = target
    #             while next_iter:
    #                 if tmp_decl.name and tmp_decl.name != 'p':
    #                     next_iter -= 1
    #                 tmp_decl = tmp_decl.next_sibling
    #             if tmp_decl:
    #                 tmp_decl = tmp_decl.next_sibling
    #             if  tmp_decl.name == 'p' and 'decl' in tmp_decl['class']:
    #                 tmp_decl.a['class'] = ['symbol-enumerations']
    #             elif target.a.has_attr('class') and 'symbol-enumerations' not in target.a['class']:
    #                 target.a['class'].append('symbol-enumerations')
    #             else:
    #                 target.a['class'] = ['symbol-enumerations']
    #         target = target.next_sibling
    #     return
    if 'Constructors' in soup.text:
        target = soup.next_sibling
        while target != None and target.name != 'h2':
            if target and target.name == 'h3':
                tmp = BeautifulSoup(str(target), 'html.parser')
                target_a = tmp.select_one('a')
                if not target_a:
                    pass
                elif target_a.has_attr('class') and 'symbol-constructors' not in target_a['class']:
                    target_a['class'].append('symbol-constructors')
                    if 'symbol-functions' in target_a['class']:
                        target_a['class'].remove('symbol-functions')
                        target.a.replace_with(target_a)
                else:
                    target_a['class'] = ['symbol-constructors']
                    target.a.replace_with(target_a)

            target = target.next_sibling
        return
    if 'Member Functions' in soup.text or soup.text or 'Destructor' in soup.text:
        target = soup.next_sibling
        while target != None and target.name != 'h2':
            if target and target.name == 'h3':
                tmp = BeautifulSoup(str(target), 'html.parser')
                target_a = tmp.select_one('a')
                if not target_a:
                    pass
                elif target_a.has_attr('class') and 'symbol-functions' not in target_a['class']:
                    target_a['class'].append('symbol-functions')
                    target.a.replace_with(target_a)
                else:
                    target_a['class'] = ['symbol-functions']
                    target.a.replace_with(target_a)
            target = target.next_sibling


def main():
    files = all_html_files()
    for file in files:
        with open(file, 'r') as f:
            soup = BeautifulSoup(f.read(), 'html.parser')
            print(file)
            mark_package(soup=soup)
            mark_class(soup=soup)
            mark_struct(soup=soup)
            mark_namespace(soup=soup)
        with open(file, 'w') as f:
            f.write(str(soup))


if __name__ == '__main__':
    main()  # Call the main function
